@@ -55,7 +55,7 @@ _CLOUDEVENT_MIME_TYPE = "application/cloudevents+json"
 
 _DAPR_BINDINGS = "bindings"
 _DAPR_PUBSUB = "pubsub"
-global DAPR_WORKMODE  
+global GPRC_HOST 
 _DAPR_SIDECAR_MODE = "sidecar"
 _DAPR_STANDALONE_MODE = "standalone"
 
@@ -369,7 +369,10 @@ def _configure_dapr_app(_app, function, ctx: FunctionContext):
                 print("binding {}".format(input.componentName))
             elif type == _DAPR_PUBSUB:
                 _app.subscribe(topic=input.uri, pubsub_name=input.componentName)(function)
-                if DAPR_WORKMODE == _DAPR_STANDALONE_MODE:
+                # 判断模式是sidecar还是standalone
+                if GPRC_HOST == "127.0.0.1":
+                    pass
+                else :
                     key = _app._servicer._topic_map.keys()
                     _app._servicer._topic_map["{}:{}:{}".format(input.componentName,input.uri,input.uri)]=_app._servicer._topic_map.pop(list(key)[0])
                 print("sub topic {}, pubsub name {}".format(input.uri, input.componentName))
@@ -412,7 +415,7 @@ class LazyWSGIApp:
     """
 
     def __init__(self, target=None, source=None, signature_type=None):
-        global DAPR_WORKMODE
+        
         # Support HTTP frameworks which support WSGI callables.
         # Note: this ability is currently broken in Gunicorn 20.0, and
         # environment variables should be used for configuration instead:
@@ -423,7 +426,7 @@ class LazyWSGIApp:
 
         # Placeholder for the app which will be initialized on first call
         self.app = None
-        DAPR_WORKMODE = os.getenv("APP_PROTOCOL",_DAPR_SIDECAR_MODE)
+        
     def __call__(self, *args, **kwargs):
         if not self.app:
             ff = os.getenv("FUNC_CONTEXT", "")
